@@ -4,7 +4,7 @@ from requests import cookies
 import json
 import re
 import requests
-from requests import structures
+from requests import structures, utils
 import sys
 try:
     import urlparse
@@ -49,6 +49,7 @@ def response(status_code=200, content='', headers=None, reason=None, elapsed=0,
     res._content = content
     res._content_consumed = content
     res.headers = structures.CaseInsensitiveDict(headers or {})
+    res.encoding = utils.get_encoding_from_headers(res.headers)
     res.reason = reason
     res.elapsed = datetime.timedelta(elapsed)
     res.request = request
@@ -106,7 +107,8 @@ def urlmatch(scheme=None, netloc=None, path=None, method=None, query=None):
 def handler_init_call(handler):
     setattr(handler, 'call', {
         'count': 0,
-        'called': False
+        'called': False,
+        'requests': []
     })
 
 
@@ -114,7 +116,8 @@ def handler_clean_call(handler):
     if hasattr(handler, 'call'):
         handler.call.update({
             'count': 0,
-            'called': False
+            'called': False,
+            'requests': []
         })
 
 
@@ -124,7 +127,7 @@ def handler_called(handler, *args, **kwargs):
     finally:
         handler.call['count'] += 1
         handler.call['called'] = True
-
+        handler.call['requests'].append(args[1])
 
 def remember_called(func):
     handler_init_call(func)
